@@ -1,23 +1,30 @@
-"""
-Module for parsing Simplified Chinese language txt file.
-"""
+# Copyright (C) 2021,2022 Kian-Meng Ang
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Affero General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Affero General Public License for more details.
+#
+# You should have received a copy of the GNU Affero General Public License
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
+
 import cjkwrap
 import regex as re
 from loguru import logger
 
-from ..models import Book
-from .base import BaseParser
-
+from txt2ebook.models import Book
+from txt2ebook.parsers.base import BaseParser
 
 IDEOGRAPHIC_SPACE = "\u3000"
 SPACE = "\u0020"
 NUMS_WORDS = "零一二三四五六七八九十百千两"
 FULLWIDTH_NUMS = "０１２３４５６７８９"
-
-RE_TITLE = r"书名：(.*)|【(.*)】|《(.*)》"
-RE_AUTHOR = r"作者：(.*)"
 RE_NUMS = f"[.0-9{FULLWIDTH_NUMS}{NUMS_WORDS}]"
-
 STRUCTURE_NAMES = {
     "cover": "封面",
 }
@@ -25,11 +32,18 @@ STRUCTURE_NAMES = {
 
 class ZhCnParser(BaseParser):
     """
-    Module for parsing txt format in zh-cn.
+    Module for parsing txt format in Simplified Chinese (zh-cn).
     """
 
-    re_volume: str = f"^第{RE_NUMS}*[集卷册][^。~\n]*$"
-    re_chapter: str = "|".join(
+    default_re_title: str = r"书名：(.*)|【(.*)】|《(.*)》"
+    default_re_author: str = r"作者：(.*)"
+    default_re_volume: str = "|".join(
+        [
+            f"^第{RE_NUMS}*[集卷册][^。~\n]*$",
+            f"^卷{RE_NUMS}.*$",
+        ]
+    )
+    default_re_chapter: str = "|".join(
         [
             f"^第{RE_NUMS}*[章篇回折].*$",
             "^[楔引]子[^，].*$",
@@ -38,23 +52,17 @@ class ZhCnParser(BaseParser):
             "^[内容]*简介.*$",
             "^[号番]外篇.*$",
             "^尾声$",
+            "^终章.*$",
+            "^后记.*$",
         ]
     )
 
-    def __init__(self, content: str, config: dict) -> None:
-        self.raw_content = content
-        self.book_title = config.title
-        self.authors = config.author
-        self.cover = config.cover
-        self.delete_regex = config.delete_regex
-        self.replace_regex = config.replace_regex
-        self.delete_line_regex = config.delete_line_regex
-        self.no_wrapping = config.no_wrapping
-        self.width = config.width
-
     def parse(self) -> Book:
         """
         Parse the content into volumes (optional) and chapters.
+
+        Returns:
+          txt2ebook.models.Book: The Book model
         """
         massaged_content = self.massage()
         (parsed_content, volumes, chapters) = self.parse_content(
@@ -74,55 +82,24 @@ class ZhCnParser(BaseParser):
             structure_names=STRUCTURE_NAMES,
         )
 
-    def detect_book_title(self) -> str:
-        """
-        Extract book title from the content of the txt file.
-        """
-        if self.book_title:
-            return self.book_title
-
-        match = re.search(RE_TITLE, self.raw_content)
-        if match:
-            book_title = next(
-                (title.strip() for title in match.groups() if title)
-            )
-            logger.info("Found book title: {}", book_title)
-            return book_title
-
-        logger.info("No book title found from file!")
-        return ""
-
-    def detect_authors(self) -> list:
-        """
-        Extract author from the content of the txt file.
-        """
-        if self.authors:
-            return self.authors
-
-        match = re.search(RE_AUTHOR, self.raw_content)
-        if match:
-            author = match.group(1).strip()
-            logger.info("Found author: {}", author)
-            return [author]
-
-        logger.info("No author found from file!")
-        return []
-
     def massage(self) -> str:
         """
         Massage the txt content.
+
+        Returns:
+          str: The book in parsed string
         """
         content = self.raw_content
 
         content = BaseParser.to_unix_newline(content)
 
-        if self.delete_regex:
+        if self.re_delete:
             content = self.do_delete_regex(content)
 
-        if self.replace_regex:
+        if self.re_replace:
             content = self.do_replace_regex(content)
 
-        if self.delete_line_regex:
+        if self.re_delete_line:
             content = self.do_delete_line_regex(content)
 
         if self.no_wrapping:
@@ -136,6 +113,12 @@ class ZhCnParser(BaseParser):
     def do_no_wrapping(self, content: str) -> str:
         """
         Remove wrapping. Paragraph should be in one line.
+
+        Args:
+            content (str): Massage book content
+
+        Returns:
+            str: Massage book content
         """
         # Convert to single spacing before we removed wrapping.
         lines = content.split("\n")
@@ -159,7 +142,7 @@ class ZhCnParser(BaseParser):
                 or re.match(r".*[a-zA-Z0-9]$", line)
             ):
                 unwrapped_content = unwrapped_content + line.strip() + "\n\n"
-            elif re.match(self.re_chapter, line):
+            elif re.match(self.get_regex("chapter"), line):
                 # replace full-width space with half-wdith space.
                 # looks nicer on the output.
                 header = line.replace(IDEOGRAPHIC_SPACE * 2, SPACE).replace(
@@ -176,6 +159,12 @@ class ZhCnParser(BaseParser):
     def do_wrapping(self, content: str) -> str:
         """
         Wrapping and filling CJK text.
+
+        Args:
+            content (str): Massage book content
+
+        Returns:
+            str: Massage book content
         """
         logger.info("Wrapping paragraph to width: {}", self.width)
 
