@@ -1,32 +1,34 @@
 # pylint: disable=no-value-for-parameter
+# Copyright (C) 2021,2022 Kian-Meng Ang
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Affero General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Affero General Public License for more details.
+#
+# You should have received a copy of the GNU Affero General Public License
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
+
 """
-Copyright (C) 2021,2022 Kian-Meng Ang
-
-This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU Affero General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU Affero General Public License for more details.
-
-You should have received a copy of the GNU Affero General Public License
-along with this program.  If not, see <https://www.gnu.org/licenses/>.
+Main program of txt2ebook.
 """
 
 from pathlib import Path
 from typing import Dict
 
+import click
 from bs4 import UnicodeDammit
 from dotmap import DotMap
 from loguru import logger
-import click
 
 from txt2ebook import __version__, setup_logger
+from txt2ebook.formats import create_format
 from txt2ebook.parsers import create_parser
-from txt2ebook.formatters import create_formatter
 
 
 @click.command(no_args_is_help=True)
@@ -37,6 +39,7 @@ from txt2ebook.formatters import create_formatter
     "-f",
     default="epub",
     show_default=True,
+    type=click.Choice(["epub", "txt"]),
     help="Set the export format ebook.",
 )
 @click.option(
@@ -81,6 +84,13 @@ from txt2ebook.formatters import create_formatter
     show_default=True,
     help="Enable debugging log.",
 )
+@click.option(
+    "--volume-page",
+    "-vp",
+    is_flag=True,
+    show_default=True,
+    help="Show the volume as separate page.",
+)
 @click.option(
     "--test-parsing",
     "-tp",
@@ -111,24 +121,48 @@ from txt2ebook.formatters import create_formatter
     help="CSS template for EPUB.",
 )
 @click.option(
-    "--delete-regex",
-    "-dr",
+    "--re-delete",
+    "-rd",
     multiple=True,
     help="Regex to delete word or phrase.",
 )
 @click.option(
-    "--replace-regex",
+    "--re-replace",
     "-rr",
     nargs=2,
     multiple=True,
     help="Regex to replace word or phrase.",
 )
 @click.option(
-    "--delete-line-regex",
-    "-dlr",
+    "--re-delete-line",
+    "-rl",
     multiple=True,
     help="Regex to delete whole line.",
 )
+@click.option(
+    "--re-volume",
+    "-rv",
+    multiple=True,
+    help="Regex to parse volume header.",
+)
+@click.option(
+    "--re-chapter",
+    "-rc",
+    multiple=True,
+    help="Regex to parse chapter header.",
+)
+@click.option(
+    "--re-author",
+    "-ra",
+    multiple=True,
+    help="Regex to parse author of the book.",
+)
+@click.option(
+    "--re-title",
+    "-rt",
+    multiple=True,
+    help="Regex to parse title of the book.",
+)
 @click.version_option(prog_name="txt2ebook", version=__version__)
 def main(**kwargs: Dict) -> None:
     """
@@ -165,14 +199,14 @@ def main(**kwargs: Dict) -> None:
 
             if not config.test_parsing:
                 if book.parsed_content:
-                    writer = create_formatter(book, config)
+                    writer = create_format(book, config)
                     writer.write()
 
                 # We write to txt for debugging purpose if output format is not
                 # txt.
                 if config.format != "txt":
                     config.format = "txt"
-                    txt_writer = create_formatter(book, config)
+                    txt_writer = create_format(book, config)
                     txt_writer.write()
 
     except RuntimeError as error:
@@ -180,4 +214,5 @@ def main(**kwargs: Dict) -> None:
 
 
 if __name__ == "__main__":
-    main()
+    main()  # pragma: no cover
+    raise SystemExit()  # pragma: no cover
